# NLDESA - Nonlinear Differential Equation Stability Analysis

This is a Python package for the stability analysis of nonlinear differential equations using JAX [1] and pyDMD [2] [3].
The package is still in development and is not yet ready for use.

Author: João Biu (joaopedrofbiu@tecnico.ulisboa.pt)

[1] https://github.com/google/jax

[2] https://github.com/PyDMD/PyDMD.git

[3] Demo et al., (2018). PyDMD: Python Dynamic Mode Decomposition. Journal of Open Source Software, 3(22), 530, https://doi.org/10.21105/joss.00530
